import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ManifestConfig extends cdktf.TerraformMetaArguments {
    /**
    * Default to update in-place. Setting to true will delete and create the kubernetes instead.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#force_new Manifest#force_new}
    */
    readonly forceNew?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#id Manifest#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * List of yaml keys to ignore changes to. Set these for fields set by Operators or other processes in kubernetes and as such you don't want to update.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#ignore_fields Manifest#ignore_fields}
    */
    readonly ignoreFields?: string[];
    /**
    * List of yaml keys with sensitive values. Set these for fields which you want obfuscated in the yaml_body output
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#sensitive_fields Manifest#sensitive_fields}
    */
    readonly sensitiveFields?: string[];
    /**
    * Default to true (validate). Set this flag to not validate the yaml schema before appying.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#validate_schema Manifest#validate_schema}
    */
    readonly validateSchema?: boolean | cdktf.IResolvable;
    /**
    * Default to true (waiting). Set this flag to wait or not for Deployments and APIService to complete rollout
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#wait_for_rollout Manifest#wait_for_rollout}
    */
    readonly waitForRollout?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#yaml_body Manifest#yaml_body}
    */
    readonly yamlBody: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#timeouts Manifest#timeouts}
    */
    readonly timeouts?: ManifestTimeouts;
}
export interface ManifestTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#create Manifest#create}
    */
    readonly create?: string;
}
export declare function manifestTimeoutsToTerraform(struct?: ManifestTimeouts | cdktf.IResolvable): any;
export declare function manifestTimeoutsToHclTerraform(struct?: ManifestTimeouts | cdktf.IResolvable): any;
export declare class ManifestTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ManifestTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: ManifestTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest kubectl_manifest}
*/
export declare class Manifest extends cdktf.TerraformResource {
    static readonly tfResourceType = "kubectl_manifest";
    /**
    * Generates CDKTF code for importing a Manifest resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Manifest to import
    * @param importFromId The id of the existing Manifest that should be imported. Refer to the {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Manifest to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/gavinbunney/kubectl/1.7.2/docs/resources/manifest kubectl_manifest} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ManifestConfig
    */
    constructor(scope: Construct, id: string, config: ManifestConfig);
    get apiVersion(): string;
    private _forceNew?;
    get forceNew(): boolean | cdktf.IResolvable;
    set forceNew(value: boolean | cdktf.IResolvable);
    resetForceNew(): void;
    get forceNewInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ignoreFields?;
    get ignoreFields(): string[];
    set ignoreFields(value: string[]);
    resetIgnoreFields(): void;
    get ignoreFieldsInput(): string[] | undefined;
    get kind(): string;
    get liveManifestIncluster(): string;
    get liveResourceVersion(): string;
    get liveUid(): string;
    get name(): string;
    get namespace(): string;
    get resourceVersion(): string;
    private _sensitiveFields?;
    get sensitiveFields(): string[];
    set sensitiveFields(value: string[]);
    resetSensitiveFields(): void;
    get sensitiveFieldsInput(): string[] | undefined;
    get uid(): string;
    private _validateSchema?;
    get validateSchema(): boolean | cdktf.IResolvable;
    set validateSchema(value: boolean | cdktf.IResolvable);
    resetValidateSchema(): void;
    get validateSchemaInput(): boolean | cdktf.IResolvable | undefined;
    private _waitForRollout?;
    get waitForRollout(): boolean | cdktf.IResolvable;
    set waitForRollout(value: boolean | cdktf.IResolvable);
    resetWaitForRollout(): void;
    get waitForRolloutInput(): boolean | cdktf.IResolvable | undefined;
    private _yamlBody?;
    get yamlBody(): string;
    set yamlBody(value: string);
    get yamlBodyInput(): string | undefined;
    get yamlBodyParsed(): string;
    get yamlIncluster(): string;
    private _timeouts;
    get timeouts(): ManifestTimeoutsOutputReference;
    putTimeouts(value: ManifestTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | ManifestTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
